==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/_internal/implicit/enum_with_selected_value/location_of_tip_relief_evaluation.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.gears.micro_geometry import _587
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_LocationOfTipReliefEvaluation")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_LocationOfTipReliefEvaluation",)


class EnumWithSelectedValue_LocationOfTipReliefEvaluation(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_LocationOfTipReliefEvaluation

    A specific implementation of 'EnumWithSelectedValue' for 'LocationOfTipReliefEvaluation' types.
    """

    __qualname__ = "LocationOfTipReliefEvaluation"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_LocationOfTipReliefEvaluation]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_LocationOfTipReliefEvaluation]",
    ) -> "_587.LocationOfTipReliefEvaluation":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _587.LocationOfTipReliefEvaluation
        """
        return _587.LocationOfTipReliefEvaluation

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_LocationOfTipReliefEvaluation]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _587.LocationOfTipReliefEvaluation.type_()

    @property
    def selected_value(self: "Self") -> "_587.LocationOfTipReliefEvaluation":
        """mastapy._private.gears.micro_geometry.LocationOfTipReliefEvaluation

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_587.LocationOfTipReliefEvaluation]":
        """List[mastapy._private.gears.micro_geometry.LocationOfTipReliefEvaluation]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.3.tar.gz: mastapy-14.1.3/mastapy/_private/_internal/implicit/enum_with_selected_value/location_of_tip_relief_evaluation.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears.micro_geometry import _595

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_LocationOfTipReliefEvaluation")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_LocationOfTipReliefEvaluation",)


class EnumWithSelectedValue_LocationOfTipReliefEvaluation(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_LocationOfTipReliefEvaluation

    A specific implementation of 'EnumWithSelectedValue' for 'LocationOfTipReliefEvaluation' types.
    """

    __qualname__ = "LocationOfTipReliefEvaluation"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_LocationOfTipReliefEvaluation]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_LocationOfTipReliefEvaluation]",
    ) -> "_595.LocationOfTipReliefEvaluation":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _595.LocationOfTipReliefEvaluation
        """
        return _595.LocationOfTipReliefEvaluation

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_LocationOfTipReliefEvaluation]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _595.LocationOfTipReliefEvaluation.type_()

    @property
    def selected_value(self: "Self") -> "_595.LocationOfTipReliefEvaluation":
        """mastapy.gears.micro_geometry.LocationOfTipReliefEvaluation

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_595.LocationOfTipReliefEvaluation]":
        """List[mastapy.gears.micro_geometry.LocationOfTipReliefEvaluation]

        Note:
            This property is readonly.
        """
        return None
